/**
 *
 * Copyright 2021 Florian Schmaus
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jivesoftware.smackx.iqversion.packet;

import org.jivesoftware.smack.XMPPConnection;
import org.jivesoftware.smack.packet.IqBuilder;
import org.jivesoftware.smack.packet.IqData;

public class VersionBuilder extends IqBuilder<VersionBuilder, Version> implements VersionView {

    private String name;
    private String version;
    private String os;

    VersionBuilder(IqData iqCommon) {
        super(iqCommon);
    }

    VersionBuilder(XMPPConnection connection) {
        super(connection);
    }

    VersionBuilder(String stanzaId) {
        super(stanzaId);
    }

    public VersionBuilder setName(String name) {
        this.name = name;
        return getThis();
    }

    public VersionBuilder setVersion(String version) {
        this.version = version;
        return getThis();
    }

    public VersionBuilder setOs(String os) {
        this.os = os;
        return getThis();
    }

    @Override
    public String getName() {
        return name;
    }

    @Override
    public String getVersion() {
        return version;
    }

    @Override
    public String getOs() {
        return os;
    }

    @Override
    public Version build() {
        return new Version(this);
    }

    @Override
    public VersionBuilder getThis() {
        return this;
    }
}
